package org.acme.rest.client.multipart;

import io.quarkus.test.junit.QuarkusIntegrationTest;

@QuarkusIntegrationTest
public class MultipartResourceIT extends MultipartResourceTest {
}
